@@ -129,6 +129,7 @@ static ServiceRole services[] = {
 	{ "nfs-kernel-server",      GST_ROLE_FILE_SERVER_NFS },
 	{ "nfs-user-server",        GST_ROLE_FILE_SERVER_NFS },
 	{ "nis",                    GST_ROLE_NSS },
+	{ "ntp",                    GST_ROLE_NTP_SERVER },
 	{ "ntp-server",             GST_ROLE_NTP_SERVER },
 	{ "ntp-simple",             GST_ROLE_NTP_SERVER },
 	{ "ntpd",                   GST_ROLE_NTP_SERVER },
@@ -140,10 +141,11 @@ static ServiceRole services[] = {
 	{ "pbbuttonsd",             GST_ROLE_HOTKEYS_MANAGEMENT },
 	{ "portmap",                GST_ROLE_RPC_MAPPER },
 	{ "postfix",                GST_ROLE_MTA },
+	{ "postgresql",             GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-7.4",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-8.0",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-8.1",         GST_ROLE_DATABASE_SERVER },
-	{ "postgresql",             GST_ROLE_DATABASE_SERVER },
+	{ "postgresql-8.2",         GST_ROLE_DATABASE_SERVER },
 	{ "powernowd",              GST_ROLE_CPUFREQ_MANAGEMENT },
 	{ "pptpd",                  GST_ROLE_VPN_SERVER },
 	{ "proftpd",                GST_ROLE_FILE_SERVER_FTP },
